@@ -1262,7 +1262,7 @@ void signal_destroy_window(GtkWidget *widget,gpointer user_data)
 	memset(hisfile,0,sizeof(gchar *)*10);
 	sub_menu=gtk_item_factory_get_widget(item_factory,_("<main>/ե(F)"));
 	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
-	for (i=0;i<g_list_length(glist)-MENUFILE-1;i++)
+	for (i=0;i<(gint)g_list_length(glist)-MENUFILE-1;i++)
 		hisfile[i]=g_strdup(gtk_object_get_user_data(
 							GTK_OBJECT(g_list_nth_data(glist,i+MENUFILE-1))));
 	g_list_free(glist);
