@@ -149,14 +149,23 @@ int main(int argc,char *argv[])
 			key=g_strdup_printf("history%d",i);
 			hisfile[i]=profile_get_string(profile,"tmaid",key);
 			g_free(key);
+			if (hisfile[i]==NULL)
+				break;
 			if (*hisfile[i]=='\0') {
 				g_free(hisfile[i]);
 				hisfile[i]=NULL;
-			}
-			if (hisfile[i]==NULL)
 				break;
+			}
 		}
 		/*  */
+		if (!profile_get_value(profile,"tmaid","find_arrow",
+								(gpointer)&find_arrow,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+			find_arrow=TRUE;
+		if (!profile_get_value(profile,"tmaid","find_ignorecase",
+								(gpointer)&find_ignorecase,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+			find_ignorecase=FALSE;
 		if (!profile_get_value(profile,"tmaid","find_num",
 					(gpointer)&find_num,sizeof(gint),PROFILE_VALUE_TYPE_INT))
 			find_num=0;
@@ -169,6 +178,14 @@ int main(int argc,char *argv[])
 		}
 		find_num=i;
 		/* ִ */
+		if (!profile_get_value(profile,"tmaid","replace_arrow",
+								(gpointer)&replace_arrow,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+			replace_arrow=TRUE;
+		if (!profile_get_value(profile,"tmaid","replace_ignorecase",
+								(gpointer)&replace_ignorecase,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+			replace_ignorecase=FALSE;
 		if (!profile_get_value(profile,"tmaid","replace_num",
 				(gpointer)&replace_num,sizeof(gint),PROFILE_VALUE_TYPE_INT))
 			replace_num=0;
@@ -414,6 +431,12 @@ int main(int argc,char *argv[])
 			g_free(key);
 		}
 		/*  */
+		profile_set_value(profile,"tmaid","find_arrow",
+								(gpointer)&find_arrow,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
+		profile_set_value(profile,"tmaid","find_ignorecase",
+								(gpointer)&find_ignorecase,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
 		profile_set_value(profile,"tmaid","find_num",
 				(gpointer)&find_num,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		for (i=0;i<find_num;i++) {
@@ -430,6 +453,12 @@ int main(int argc,char *argv[])
 			g_free(key);
 		}
 		/* ִ */
+		profile_set_value(profile,"tmaid","replace_arrow",
+								(gpointer)&replace_arrow,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
+		profile_set_value(profile,"tmaid","replace_ignorecase",
+								(gpointer)&replace_ignorecase,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
 		profile_set_value(profile,"tmaid","replace_num",
 				(gpointer)&replace_num,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		for (i=0;i<replace_num;i++) {
